#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xdg-basedir
version:              0.2.2
visibility:           public
id:                   xdg-basedir-0.2.2-DLaKUfv1JJAFBfkP0BUklH
key:                  xdg-basedir-0.2.2-DLaKUfv1JJAFBfkP0BUklH
license:              BSD-3-Clause
copyright:            (c) 2011 Will Donnelly
maintainer:           Will Donnelly <will.donnelly@gmail.com>
author:               Will Donnelly
stability:            alpha
homepage:             http://github.com/willdonnelly/xdg-basedir
synopsis:
    A basic implementation of the XDG Base Directory specification.

description:
    On Unix platforms, this should be a very straightforward
    implementation of the XDG Base Directory spec. On Windows,
    it will attempt to do the right thing with regards to
    choosing appropriate directories.

category:             System
abi:                  cbacbd504b3257c82a8b93bc4d98cbcb
exposed:              True
exposed-modules:      System.Environment.XDG.BaseDir
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xdg-basedir-0.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xdg-basedir-0.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xdg-basedir-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xdg-basedir
hs-libraries:         HSxdg-basedir-0.2.2-DLaKUfv1JJAFBfkP0BUklH
depends:              base-4.18.2.1 directory-1.3.8.5 filepath-1.4.300.1
haddock-interfaces:   /usr/share/doc/haskell-xdg-basedir/html/xdg-basedir.haddock
haddock-html:         /usr/share/doc/haskell-xdg-basedir/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

